.. _navier_stokes-examples-index:

navier_stokes
=============

.. toctree::
   :maxdepth: 2

   navier_stokes.py <navier_stokes-navier_stokes>
   navier_stokes2d.py <navier_stokes-navier_stokes2d>
   navier_stokes2d_iga.py <navier_stokes-navier_stokes2d_iga>
   stabilized_navier_stokes.py <navier_stokes-stabilized_navier_stokes>
   stokes.py <navier_stokes-stokes>
   stokes_slip_bc.py <navier_stokes-stokes_slip_bc>
   utils.py <navier_stokes-utils>
